@@ -6,7 +6,9 @@ from enum import StrEnum
 
 from playwright.async_api import Page, Playwright
 from pyro_client.client.file import FileClient
-from xync_client.loader import TOKEN
+from pyro_client.client.user import UserClient
+
+from xync_client.loader import NET_TOKEN
 from xync_schema.enums import UserStatus
 from xync_schema.models import PmAgent, User
 
@@ -22,29 +24,22 @@ class PmAgentClient(metaclass=ABCMeta):
         OTP_LOGIN = base + "login/otp"
 
     norm: str
-    uid: int
     agent: PmAgent
-    bot: FileClient
+    bot: FileClient | UserClient
     page: Page
     pages: type(StrEnum) = Pages
     last_page: int = 0
     last_active: datetime = datetime.now()
     _is_started: bool = False
 
-    async def start(self, pw: Playwright, headed: bool = False) -> "PmAgentClient":
-        dct = dict(user__status__gte=UserStatus.PAY, pm__norm=self.norm)
-        if self.uid:
-            dct.update({"user__username_id": self.uid})
-
-        self.bot = FileClient(TOKEN)
+    async def start(self, pw: Playwright, headed: bool = False, userbot: bool = False) -> "PmAgentClient":
+        bot = FileClient(NET_TOKEN)
+        self.bot = UserClient(self.uid, bot) if userbot else bot
         await self.bot.start()
 
-        self.agent = await PmAgent.get_or_none(**dct).prefetch_related("user__username__session")
-        if not self.agent:
-            await self.bot.send(f"No active users with agent for {self.norm}!", self.uid)
-            raise Exception(f"No active users for {self.norm}!")
-
-        self.browser = await pw.chromium.launch(channel="chromium-headless-shell", headless=not headed)
+        self.browser = await pw.chromium.launch(
+            channel="chromium" if headed else "chromium-headless-shell", headless=not headed
+        )
         context = await self.browser.new_context(storage_state=self.agent.state)
         self.page = await context.new_page()
         await self.page.goto(self.pages.SEND)  # Оптимистично переходим сразу на страницу отправки
@@ -59,6 +54,8 @@ class PmAgentClient(metaclass=ABCMeta):
         self._is_started = True
         return self
 
+    def get_topup(self, tid: str) -> dict: ...
+
     async def _idle(self):  # todo: не мешать другим процессам, обновлять на другой вкладке?
         while (await User.get(username_id=self.uid)).status >= UserStatus.ACTIVE:
             await self.page.wait_for_timeout(30 * 1000)
@@ -90,5 +87,7 @@ class PmAgentClient(metaclass=ABCMeta):
     @abstractmethod  # видео входа в аккаунт, и переход в историю поступлений за последние сутки (минимум)
     async def proof(self) -> bytes: ...
 
-    def __init__(self, uid: int = None):
-        self.uid = uid
+    def __init__(self, agent: PmAgent):
+        self.agent = agent
+        self.uid = agent.user.username_id
+        self.norm = agent.pm.norm
