@@ -19,7 +19,6 @@ from xync_client.Abc.PmAgent import PmAgentClient
 from xync_schema import models
 from xync_schema.enums import UserStatus, OrderStatus
 
-from xync_client.Pms.Payeer import Client
 from xync_client.Bybit.etype.order import (
     StatusChange,
     CountDown,
@@ -29,7 +28,7 @@ from xync_client.Bybit.etype.order import (
     OrderFull,
     StatusApi,
 )
-from xync_client.loader import TOKEN
+from xync_client.loader import NET_TOKEN
 from xync_client.Abc.InAgent import BaseInAgentClient
 from xync_client.Bybit.agent import AgentClient
 
@@ -407,17 +406,18 @@ async def main():
             person__user__status=UserStatus.ACTIVE,
             person__user__pm_agents__isnull=False,
         )
-        .prefetch_related("ex", "agent", "person__user__pm_agents")
+        .prefetch_related("ex", "agent", "person__user__pm_agents__user", "person__user__pm_agents__pm")
         .first()
     )
 
-    async with FileClient(TOKEN) as b:
+    async with FileClient(NET_TOKEN) as b:
         b: FileClient
         cl: InAgentClient = actor.in_client(b)
         # await cl.agent_client.export_my_ads()
-        payeer_cl = Client(actor.person.user.username_id)
+        # payeer_cl = Client(actor.person.user.username_id)
         for pma in actor.person.user.pm_agents:
-            cl.pmacs[pma.pm_id] = await payeer_cl.start(await async_playwright().start(), False)
+            pcl = pma.client()
+            cl.pmacs[pma.pm_id] = await pcl.start(await async_playwright().start(), False)
         try:
             _ = await cl.start_listen()
         except Exception as e:
