@@ -43,7 +43,7 @@ from xync_client.Bybit.etype.order import (
     Message,
     Status,
 )
-from xync_client.loader import TORM, TOKEN
+from xync_client.loader import TORM, NET_TOKEN
 
 
 class NoMakerException(Exception):
@@ -1264,7 +1264,7 @@ async def main():
     actor = (
         await models.Actor.filter(ex_id=4, agent__isnull=False).prefetch_related("ex", "agent", "person__user").first()
     )
-    filebot = FileClient(TOKEN)
+    filebot = FileClient(NET_TOKEN)
     await filebot.start()
     # b.add_handler(MessageHandler(cond_start_handler, command("cond")))
     cl: AgentClient = actor.client(filebot)
@@ -1315,10 +1315,10 @@ async def main():
     hist |= papi.history(count=1000, append=list(hist.keys())[-1])
     cl.hist = hist
 
-    cl.completed_orders = await models.Order.filter(status=OrderStatus.completed, transfer__isnull=False).values_list(
-        "exid", flat=True
-    )
-    await cl.get_api_orders()  # 43, 1741294800000, 1749157199999)
+    # cl.completed_orders = await models.Order.filter(status=OrderStatus.completed, transfer__isnull=False).values_list(
+    #     "exid", flat=True
+    # )
+    # await cl.get_api_orders()  # 43, 1741294800000, 1749157199999)
 
     races = await models.Race.filter(started=True).prefetch_related(
         "road__ad__pair_side__pair__cur",
