@@ -19,7 +19,7 @@ from cryptography.hazmat.primitives.ciphers.modes import CBC
 from payeer_api import PayeerAPI
 from playwright.async_api import async_playwright, Playwright, Error
 from playwright._impl._errors import TimeoutError
-from xync_schema.models import TopUp, TopUpAble
+from xync_schema.models import TopUp, TopUpAble, PmAgent
 
 from xync_client.loader import TORM
 
@@ -65,11 +65,10 @@ class Client(PmAgentClient):
     pages: type(StrEnum) = Pages
     api: PayeerAPI
 
-    async def start(self, pw: Playwright, headed: bool = False) -> "PmAgentClient":
-        await super().start(pw, headed)
+    def __init__(self, agent: PmAgent):
+        super().__init__(agent)
         if api_id := self.agent.auth.get("api_id"):
             self.api = PayeerAPI(self.agent.auth["email"], api_id, self.agent.auth["api_sec"])
-        return self
 
     async def _login(self):
         await login(self.agent)
@@ -121,6 +120,17 @@ class Client(PmAgentClient):
         url = "https://payeer.com/merchant/?" + urlencode(params)
         return url, None
 
+    def get_topup(self, tid: str) -> dict:
+        hi = self.api.get_history_info(tid)
+        ti = self.api.shop_order_info(hi["params"]["SHOP_ID"], hi["params"]["ORDER_ID"])["info"]
+        return ti["status"] == "execute" and {
+            "pmid": ti["id"],
+            "from_acc": hi["params"]["ACCOUNT_NUMBER"],
+            "oid": hi["params"]["ORDER_ID"],
+            "amount": int(float(ti["sumOut"]) * 100),
+            "ts": datetime.strptime(ti["dateCreate"], "%d.%m.%Y %H:%M:%S") - timedelta(hours=3),
+        }
+
     async def send(self, dest: str, amount: int, cur: str) -> tuple[int, bytes, int] | int:
         self.last_active = datetime.now()
         page = self.page
@@ -204,8 +214,13 @@ async def main(uid: int):
     from x_model import init_db
 
     _ = await init_db(TORM, True)
+    agent = await PmAgent.get_or_none(pm__norm="payeer", user__username_id=uid).prefetch_related(
+        "user__username__session", "pm"
+    )
+    if not agent:
+        raise Exception(f"No active user #{uid} with agent for volet!")
+    pyr = agent.client()
     playwright: Playwright = await async_playwright().start()
-    pyr = Client(uid)
     try:
         dest, amount, cur = "P79619335", 4, "RUB"
         ta = await TopUpAble.get(pm__norm="payeer")
