@@ -1,22 +1,23 @@
 import logging
 import re
 from asyncio import run, ensure_future
+from decimal import Decimal
 from enum import StrEnum
-from typing import Literal
+from hashlib import sha256
 
 from playwright.async_api import async_playwright, Page, Locator, Position, Playwright  # , FloatRect
 from pyotp import TOTP
 
 # noinspection PyProtectedMember
 from playwright._impl._errors import TimeoutError
-from pyro_client.client.bot import BotClient
 from pyro_client.client.user import UserClient
+from pyrogram.handlers import MessageHandler
 from xync_schema.enums import UserStatus
-from xync_schema.models import Cur, User, PmAgent, Cred, PmCur, Fiat
+from xync_schema.models import Cur, User, PmAgent, Cred, PmCur, Fiat, TopUp
 
+from xync_client.Abc.PmAgent import PmAgentClient
 from xync_client.Gmail import GmClient
 from xync_client.Pms.Volet.api import APIClient
-from xync_client.loader import TOKEN
 
 
 class CaptchaException(Exception): ...
@@ -31,14 +32,6 @@ class NoCodeException(Exception): ...
 class NoMailException(Exception): ...
 
 
-class Pages(StrEnum):
-    base_url = "https://account.volet.com/"
-    LOGIN = base_url + "login"
-    OTP_LOGIN = base_url + "login/otp"
-    HOME = base_url + "pages/transaction"
-    SEND = base_url + "pages/transfer/wallet"
-
-
 def parse_transaction_info(text: str) -> dict[str, str] | None:
     # Поиск ID транзакции
     transaction_id_match = re.search(r"Transaction ID:\s*([\w-]+)", text)
@@ -57,65 +50,101 @@ def parse_transaction_info(text: str) -> dict[str, str] | None:
     return None
 
 
-class Client:
+class Client(PmAgentClient):
+    class Pages(StrEnum):
+        base = "https://account.volet.com/"
+        LOGIN = base + "login"
+        OTP_LOGIN = base + "login/otp"
+        # HOME = base + "pages/transaction"
+        SEND = base + "pages/transfer/wallet"
+
+    async def check_in(self, amount: int | Decimal | float, cur: str, tid: str | int = None) -> float | None:
+        pass
+
+    async def proof(self) -> bytes:
+        pass
+
     uid: int
     agent: PmAgent
     bot: UserClient
     api: APIClient
     page: Page
     gmail: GmClient
+    norm: str = "payeer"
+    pages: type(StrEnum) = Pages
 
-    def __init__(self, uid: int):
-        self.uid = uid
-        self.gmail = GmClient(uid)
+    def __init__(self, agent: PmAgent):
+        super().__init__(agent)
+        self.gmail = GmClient(self.uid)
+        self.api = APIClient(self.agent.auth["api"], self.agent.auth["password"], self.agent.auth["login"])
+
+    @staticmethod
+    def form_redirect(topup: TopUp) -> tuple[str, dict | None]:
+        ac_account_email = topup.topupable.auth["ac_account_email"]
+        ac_sci_name = topup.topupable.auth["ac_sci_name"]
+        ac_order_id = str(topup.id)
+        ac_amount = "{0:.2f}".format(topup.amount * 0.01)
+        ac_currency = topup.cur.ticker
+        ac_comments = "XyncPay top up"
+        secret = topup.topupable.auth["secret"]
+        data = [ac_account_email, ac_sci_name, ac_amount, ac_currency, secret, ac_order_id]
+
+        ac_sign = sha256(":".join(data).encode()).hexdigest()
+
+        params = {
+            "ac_account_email": ac_account_email,
+            "ac_sci_name": ac_sci_name,
+            "ac_amount": ac_amount,
+            "ac_currency": ac_currency,
+            "ac_order_id": ac_order_id,
+            "ac_sign": ac_sign,
+            "ac_comments": ac_comments,
+        }
+        url = "https://account.volet.com/sci/"
+        return url, params
+
+    def get_topup(self, tid: str) -> dict:
+        t = self.api.check_by_id(tid)
+        return t["status"] == "COMPLETED" and {
+            "pmid": t["id"],
+            "from_acc": t["walletSrcId"],
+            "oid": t["orderId"],
+            "amount": int(t["amount"] * 100),
+            "ts": t["updatedTime"],
+        }
 
     async def start(self, pw: Playwright, headed: bool = False):
-        self.agent = await PmAgent.get(
-            user__username_id=self.uid, user__status__gte=UserStatus.PAY, pm__norm="volet"
-        ).prefetch_related("user__gmail", "user__username__session")
-        self.api = APIClient(self.agent.auth["api"], self.agent.auth["password"], self.agent.auth["login"])
-        # await self.upd_balances()
-        bot = await BotClient(TOKEN)
-        self.bot = await UserClient(self.uid, bot)
-        await self.bot.start()
+        ensure_future(self.gmail.start(pw, False))
+        return await super().start(pw, False, True)
 
-        browser = await pw.chromium.launch(channel="chrome", headless=not headed, timeout=9000)
-        context = await browser.new_context(storage_state=self.agent.state, locale="en")
-        self.page = await context.new_page()
-        ensure_future(self.gmail.start(pw, headed))
-        await self.go(Pages.HOME)
-        if self.page.url == Pages.LOGIN:
-            await self.login()
-        # elif self.page.url == Pages.OTP_LOGIN:
-        #     await self.login_otp()
-        if self.page.url != Pages.HOME:
-            await self.bot.receive("Not logged in!", photo=await self.page.screenshot())
-            raise Exception(f"User {self.agent.user_id} has not logged in")
+    async def wait_for_code(self, uid: int, topic: str, hg: tuple[MessageHandler, int]) -> str:
+        code = await self.bot.wait_from(uid, topic, hg)
+        return code and code[-6:]
 
-    async def wait_for_code(self, typ: Literal["login", "send"]) -> str:
-        code = await self.bot.wait_from(243630567, f"otp_{typ}")
-        return code[-6:]
-
-    async def login(self):
-        await self.page.locator("input#j_username").fill("mixartemev@gmail.com")
+    async def _login(self):
+        ll = self.page.locator("input#j_username")
+        await ll.fill("mixartemev@gmail.com")
         await self.page.locator("input#j_password").fill("mixfixX98")
+        await self.page.wait_for_timeout(200)
+        await ll.click()
+        volet_bot_id, topic = 243630567, "otp_login"
         await self.page.locator("input#loginToAdvcashButton", has_text="log in").hover()
+        hg = self.bot.subscribe_for(volet_bot_id, topic)  # 243630567 - is volet bot
         await self.page.locator("input#loginToAdvcashButton:not([disabled])", has_text="log in").click()
-        await self.page.wait_for_url(Pages.OTP_LOGIN)
-        await self.login_otp()
-
-    async def login_otp(self):
-        if not (code := await self.wait_for_code("login")):
+        await self.page.wait_for_url(self.pages.OTP_LOGIN)
+        if not (code := await self.wait_for_code(volet_bot_id, topic, hg)):
             await self.bot.receive("no login code", photo=await self.page.screenshot())
             raise NoCodeException(self.agent.user_id)
         await self.page.locator("input#otpId").fill(code)
         await self.page.click("input#checkOtpButton")
-        await self.page.wait_for_url(Pages.HOME)
+        await self.page.wait_for_url(self.pages.SEND)
 
-    async def send(self, dest: str, amount: float):
-        await self.go(Pages.SEND)
+    async def send(self, dest: str, amount: float, cur: str) -> tuple[int, bytes, float]:
+        curs_map = {"RUB": "Ruble"}
+
+        await self.go(self.pages.SEND)
         await self.page.click("[class=combobox-account]")
-        await self.page.click('[class=rf-ulst-itm] b:has-text("Ruble ")')
+        await self.page.click(f'[class=rf-ulst-itm] b:has-text("{curs_map[cur]}") ")')
         await self.page.wait_for_timeout(200)
         await self.page.fill("#srcAmount", str(amount))
         await self.page.fill("#destWalletId", dest)
@@ -135,7 +164,7 @@ class Client:
             raise OtpNotSetException(self.agent.user_id)
         await self.page.fill("#securityValue", code)
         await self.page.locator("input[type=submit]", has_text="confirm").click()
-        await self.page.wait_for_url(Pages.SEND)
+        await self.page.wait_for_url(self.pages.SEND)
         await self.page.get_by_role("heading").click()
         slip = await self.page.screenshot(clip={"x": 440, "y": 205, "width": 420, "height": 360})
         await self.bot.receive(f"{amount} to {dest} sent", photo=slip)
@@ -223,7 +252,13 @@ async def _test():
     logging.basicConfig(level=logging.DEBUG)
     uid = 193017646
     playwright: Playwright = await async_playwright().start()
-    va = Client(uid)
+    agent = await PmAgent.get_or_none(pm__norm="volet", user__username_id=uid).prefetch_related(
+        "user__username__session"
+    )
+    if not agent:
+        raise Exception(f"No active user #{uid} with agent for volet!")
+
+    va = agent.client()
     try:
         await va.start(playwright)
         await va.send("alena.artemeva25@gmail.com", 7.98)
