@@ -16,7 +16,7 @@ from xync_client.TgWallet.pyd import (
     _PmsTrait,
     _BaseAd,
 )
-from xync_client.loader import TOKEN, TORM
+from xync_client.loader import NET_TOKEN, TORM
 from xync_client.Abc.Ex import BaseExClient
 from xync_client.Abc.xtype import MapOfIdsList
 from xync_client.TgWallet.auth import AuthClient
@@ -156,7 +156,7 @@ class ExClient(BaseExClient, AuthClient):
 async def _test():
     await init_db(TORM)
     tgex = await models.Ex.get(name="TgWallet")
-    async with FileClient(TOKEN) as b:
+    async with FileClient(NET_TOKEN) as b:
         cl: ExClient = tgex.client(b)
 
         await cl.set_coins()
