@@ -4,7 +4,7 @@ from xync_schema import models
 
 load_dotenv()
 
-TOKEN = env("TOKEN")
+NET_TOKEN = env("NET_TOKEN")
 PG_DSN = f"postgres://{env('POSTGRES_USER')}:{env('POSTGRES_PASSWORD')}@{env('POSTGRES_HOST', 'xyncdbs')}:{env('POSTGRES_PORT', 5432)}/{env('POSTGRES_DB', env('POSTGRES_USER'))}"
 TORM = {
     "connections": {"default": PG_DSN},
